# Registries of NuCypher Networks

This repo contains an authorative source of contract registries for several NuCypher networks.


## Current networks

* **Mainnet**: (_Coming soon..._)
* **LTS**: Public long-term support testnet (_Coming soon... # TODO: Name this testnet_)
* **Ibex**: Internal testnet. Mainly for development purposes. You're free to join, but note that we may reboot this testnet without prior notice.

## Historical networks

Some networks that we used at some point in the past that are currently deprecated.

* **Miranda**: Our first decentralized testnet.
* **Frances**: Our second testnet. Only for development purposes.
* **Cassandra**: Incentivized Testnet, supporting our 'Come and Stake It' initiative.
* **Gemini**: New version of Incentivized Testnet, supporting Phase 4 of 'Come and Stake It'.
